@@ -27,6 +27,7 @@ enum {
   LOG_PEER_INFO,
   LOG_PEER_DEBUG,
 
+  // TODO: Deprecate, not used.
   LOG_SOCKET_CRITICAL,
   LOG_SOCKET_ERROR,
   LOG_SOCKET_WARN,
@@ -81,6 +82,7 @@ enum {
   LOG_MOCK_CALLS,
 
   LOG_NET_DNS,
+  LOG_NET_SOCKET,
 
   LOG_PEER_LIST_EVENTS,
   LOG_PEER_LIST_ADDRESS,
@@ -207,7 +209,7 @@ void log_remove_group_output(int group, const char* name) LIBTORRENT_EXPORT;
 void log_add_child(int group, int child) LIBTORRENT_EXPORT;
 void log_remove_child(int group, int child) LIBTORRENT_EXPORT;
 
-void log_open_file_output(const char* name, const char* filename, bool append = false) LIBTORRENT_EXPORT;
+void log_open_file_output(const char* name, const char* filename, bool append = false, bool flush = false) LIBTORRENT_EXPORT;
 void log_open_gz_file_output(const char* name, const char* filename, bool append = false) LIBTORRENT_EXPORT;
 
 //
